
import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';
import { MainService } from 'src/app/services/main.service';



@Component({
  selector: 'app-boilerplate-details',
  templateUrl: './boilerplate-details.component.html',
  styleUrls: ['./boilerplate-details.component.scss']
})
export class BoilerplateDetailsComponent implements OnInit {

  panelOpenState = false;

  subjects:string[] = [];
  
  systems:string[] = [];
  subclassystems:string[] = [];
  instacesystems:string[] = [];
  
  functions:string[] = [];
  subclasfunctions:string[] = [];
  instacefunctions:string[] = [];

  items:string[] = [];
  subclasitems:string[] = [];
  instaceitems:string[] = [];

  interfaces:string[] = [];
  subclasinterfaces:string[] = [];
  instaceinterfaces:string[] = [];

  connections:string[] = [];
  subclasconnections:string[] = [];
  instaceconnections:string[] = [];

  flows:string[] = [];
  subclasflows:string[] = [];
  instaceflows:string[] = [];

  states:string[] = [];
  subclasstates:string[] = [];
  instacestates:string[] = [];


  currentboilerplate: Boilerplate = {
    has_prefix: false,
    has_main: false,
    has_suffix: false
  };
  message = '';

  constructor(
    private mainService: MainService,
    private boilerplateService: BoilerplateService,
    private route: ActivatedRoute,
    private router: Router) { }

  ngOnInit(): void {
    this.message = '';
    this.getchoices(); 
    this.getBoilerplate(this.route.snapshot.params.gb, this.route.snapshot.params.id);
  }

  getBoilerplate(gb:any, id: number): void {
    this.boilerplateService.get(gb, id)
      .subscribe(
        data => {
          this.currentboilerplate = data;
          console.log(data);
        },
        error => {
          console.log(error);
        });
  }

  updateBoilerplate(): void {
    this.boilerplateService.update(this.route.snapshot.params.gb, this.currentboilerplate.id, this.currentboilerplate)
      .subscribe(
        response => {
          console.log(response);
          this.message = response.message;
          window.location.reload();
        },
        error => {
          console.log(error);
        });
  }

  deleteBoilerplate(): void {
    if(confirm("Αre you sure you want to delete this Boilerplate?")) {
      this.boilerplateService.delete(this.route.snapshot.params.gb, this.currentboilerplate.id)
        .subscribe(
          response => {
            console.log(response);
            this.router.navigate(['/groupboilerplates/'+ this.route.snapshot.params.gb +'/boilerplates']);
          },
          error => {
            console.log(error);
          });
      }
  }

  getchoices(): void{
    //System
    this.mainService.getclasssystem()
      .subscribe(
        data => {
              this.systems = data
        },
        error => {
          console.log(error);
        });

      this.mainService.getinstancesystem()
      .subscribe(
        data => {
              this.instacesystems = data
        },
        error => {
          console.log(error);
        });

        this.mainService.getsubclassystem()
      .subscribe(
        data => {
              this.subclassystems = data
        },
        error => {
          console.log(error);
        });

    //Function
    this.mainService.getclassfunction()
      .subscribe(
        data => {
              this.functions = data
        },
        error => {
          console.log(error);
        });

      this.mainService.getinstancefunction()
      .subscribe(
        data => {
              this.instacefunctions = data
        },
        error => {
          console.log(error);
        });

        this.mainService.getsubclasfunction()
      .subscribe(
        data => {
              this.subclasfunctions = data
        },
        error => {
          console.log(error);
        });
    
    //Item
      this.mainService.getclassitem()
      .subscribe(
        data => {
              this.items = data
        },
        error => {
          console.log(error);
        });

      this.mainService.getinstanceitem()
      .subscribe(
        data => {
              this.instaceitems = data
        },
        error => {
          console.log(error);
        });

        this.mainService.getsubclasitem()
      .subscribe(
        data => {
              this.subclasitems = data
        },
        error => {
          console.log(error);
        });
    //Interface
    this.mainService.getclassinterface()
    .subscribe(
      data => {
            this.interfaces = data
      },
      error => {
        console.log(error);
      });

    this.mainService.getinstanceinterface()
    .subscribe(
      data => {
            this.instaceinterfaces = data
      },
      error => {
        console.log(error);
      });

      this.mainService.getsubclasinterface()
    .subscribe(
      data => {
            this.subclasinterfaces = data
      },
      error => {
        console.log(error);
      });
    //Connection
    this.mainService.getclassconnection()
    .subscribe(
      data => {
            this.connections = data
      },
      error => {
        console.log(error);
      });

    this.mainService.getinstanceconnection()
    .subscribe(
      data => {
            this.instaceconnections = data
      },
      error => {
        console.log(error);
      });

      this.mainService.getsubclasconnection()
    .subscribe(
      data => {
            this.subclasconnections = data
      },
      error => {
        console.log(error);
      });
    //Flow
    this.mainService.getclassflow()
    .subscribe(
      data => {
            this.flows = data
      },
      error => {
        console.log(error);
      });

    this.mainService.getinstanceflow()
    .subscribe(
      data => {
            this.instaceflows = data
      },
      error => {
        console.log(error);
      });

      this.mainService.getsubclasflow()
    .subscribe(
      data => {
            this.subclasflows = data
      },
      error => {
        console.log(error);
      });
    //State
    this.mainService.getclassstate()
    .subscribe(
      data => {
            this.states = data
      },
      error => {
        console.log(error);
      });

    this.mainService.getinstancestate()
    .subscribe(
      data => {
            this.instacestates = data
            console.log(data)
      },
      error => {
        console.log(error);
      });

      this.mainService.getsubclasstate()
    .subscribe(
      data => {
            this.subclasstates = data
      },
      error => {
        console.log(error);
      });
  }
      
  checkeven(i:any): any {
    if (i%2 == 0){ return true}
    return false
  }

  checkthree(i:any): any {
    if (i%3 == 0){ return true}
    return false
  }

  checklen(i:any): any {
    if (i.length>1){ return true}
    return false
  }
}
